@@ -15,10 +15,6 @@ from statefun_tasks.protobuf import pack_any, unpack_any
 from statefun_tasks.serialisation import DefaultSerialiser
 
 
-# storage
-from statefun_tasks.storage import StorageBackend
-
-
 # types
 from statefun_tasks.types import Task, Group, RetryPolicy, TaskAlreadyExistsException, TaskCancelledException, TasksException, PipelineInProgress, YieldTaskInvocation
 from statefun_tasks.type_helpers import flink_value_type_for
@@ -26,4 +22,4 @@ from statefun_tasks.type_helpers import flink_value_type_for
 
 # protobuf message types
 from statefun_tasks.messages_pb2 import TaskRequest, TaskResult, TaskException, TaskActionRequest, TaskActionResult, \
-    TaskActionException, TaskAction, TaskStatus, TaskDeferral, PausedTask, ChildPipeline, Address, TaskInfo
+    TaskActionException, TaskAction, TaskStatus, TaskDeferral, PausedTask, ChildPipeline, Address, TaskInfo, DeferredTask
