@@ -32,7 +32,8 @@ class BeginPipelineHandler(PipelineMessageHandler):
         context.pipeline_state.status.value = TaskStatus.RUNNING
         context.pipeline_state.pipeline.CopyFrom(pipeline.to_proto())
         context.pipeline_state.is_fruitful = pipeline.is_fruitful
-        context.pipeline_state.task_state.CopyFrom(pack_any(self.serialiser.to_proto(state)))
+        context.pipeline_state.task_state.CopyFrom(pack_any(self.serialiser.to_proto(state)))  # state of task calling this pipeline
+        context.pipeline_state.last_task_state.CopyFrom(context.pipeline_state.pipeline.initial_state) # state of last task called within this pipeline
         context.pipeline_state.invocation_id = _gen_id()
 
         if caller_id is not None:
@@ -63,18 +64,19 @@ class BeginPipelineHandler(PipelineMessageHandler):
         else:
             # else get initial tasks(s) to call - might be single start of chain task or a group of tasks to call in parallel
             tasks, max_parallelism, slice = self.graph.get_initial_tasks()
+            task_state, initial_args, initial_kwargs = None, None, None
 
             # send initial state to each initial task if we have some
-            if context.pipeline_state.pipeline.HasField('initial_state'):                
+            if context.pipeline_state.pipeline.HasField('initial_state'):   
                 task_state = unpack_any(context.pipeline_state.pipeline.initial_state, known_proto_types=[])
-            else:
-                task_state = None
 
             # send initial arguments to each initial task if we have them
             if context.pipeline_state.pipeline.HasField('initial_args'):
                 initial_args = unpack_any(context.pipeline_state.pipeline.initial_args, known_proto_types=[])
-            else:
-                initial_args = None
+
+            # send initial kwargs to each initial task if we have them
+            if context.pipeline_state.pipeline.HasField('initial_kwargs'):
+                initial_kwargs = context.pipeline_state.pipeline.initial_kwargs
 
             # if we skipped over empty group(s) then make sure we pass empty array to next task (result of in_parallel([]) is intuitively [])
             if slice > 0:
@@ -83,7 +85,13 @@ class BeginPipelineHandler(PipelineMessageHandler):
                     task.request = self._serialiser.serialise_args_and_kwargs(([]), kwargs)
 
             # split into tasks to call now and those to defer if max parallelism is exceeded
-            self.submitter.submit_tasks(context, tasks, task_state=task_state, max_parallelism=max_parallelism, initial_args=initial_args)
+            self.submitter.submit_tasks(
+                context, 
+                tasks, 
+                task_state=task_state, 
+                initial_args=initial_args, 
+                initial_kwargs=initial_kwargs,
+                max_parallelism=max_parallelism)
 
             # break
             return False, message
