@@ -1,7 +1,6 @@
 from abc import ABC, abstractmethod
 from statefun_tasks.context import TaskContext
 from statefun_tasks.serialisation import DefaultSerialiser
-from statefun_tasks.storage import StorageBackend
 from statefun_tasks.messages_pb2 import TaskRequest, TaskResult, TaskException
 from statefun_tasks.pipeline_impl.helpers import PipelineGraph, DeferredTaskSubmitter, ResultAggregator, ResultEmitter
 from google.protobuf.any_pb2 import Any
@@ -9,13 +8,12 @@ from typing import Union, Tuple
 
 
 class PipelineMessageHandler(ABC):
-    def __init__(self, pipeline, serialiser: DefaultSerialiser, storage: StorageBackend=None):
+    def __init__(self, pipeline, serialiser: DefaultSerialiser):
         self._pipeline = pipeline
         self._serialiser = serialiser
-        self._storage = storage
         self._graph = PipelineGraph(pipeline)
-        self._submitter = DeferredTaskSubmitter(self._graph, serialiser, storage)
-        self._result_aggregator = ResultAggregator(self._graph, serialiser, storage)
+        self._submitter = DeferredTaskSubmitter(self._graph, serialiser)
+        self._result_aggregator = ResultAggregator(self._graph, serialiser)
         self._result_emitter = ResultEmitter()
 
     @abstractmethod
@@ -45,7 +43,3 @@ class PipelineMessageHandler(ABC):
     @property
     def result_emitter(self):
         return self._result_emitter
-
-    @property
-    def storage(self):
-        return self._storage
