@@ -5,6 +5,8 @@ from collections import deque
 
 
 class PipelineGraph(object):
+    __slots__ = ('_pipeline')
+
     def __init__(self, pipeline: list):
         self._pipeline = pipeline
 
@@ -47,7 +49,8 @@ class PipelineGraph(object):
         raise ValueError(f'Task {task_id} not found')
 
     def is_empty(self):
-        return not any(self.get_initial_tasks())
+        tasks, _ ,_ = self.get_initial_tasks()
+        return not any(tasks)
         
     def get_task_chain(self, task_id):
         
@@ -108,12 +111,19 @@ class PipelineGraph(object):
 
         tasks = self.get_task_chain(task_id)
 
-        if failed:
-            # mark this task complete and its children
-            for task in tasks:
-                task.mark_complete()
-        elif any(tasks):
-            tasks[0].mark_complete()
+        if any(tasks):
+            if tasks[0].is_complete():
+                return False  # task already complete - ignore
+
+            if failed:
+                # mark this task complete and its children
+                for task in tasks:
+                    if not task.is_finally:
+                        task.mark_complete()
+            else:
+                tasks[0].mark_complete()
+
+        return True
          
     def try_get_finally_task(self, task_id=None):
         finally_task = next((task for task in self._pipeline if isinstance(task, Task) and task.is_finally), None)
