@@ -1,18 +1,21 @@
 from statefun_tasks.context import TaskContext
 from statefun_tasks.task_impl.handlers import MessageHandler
-from statefun_tasks.messages_pb2 import ChildPipeline
+from statefun_tasks.types import CHILD_PIPELINE_TYPE
+from statefun import Message
 
 
 class ChildPipelineHandler(MessageHandler):
     def __init__(self):
         pass
 
-    def can_handle(self, context: TaskContext, message):
-        if isinstance(message, ChildPipeline):
-            context.task_name = f'New child pipeline: {message.id}'
-            return True
+    def unpack(self, context: TaskContext, message: Message):       
+        if message.is_type(CHILD_PIPELINE_TYPE):
+            task_input = message.as_type(CHILD_PIPELINE_TYPE)
+            context.task_name = f'New child pipeline: {task_input.id}'
+            
+            return task_input
 
-        return False
+        return None
 
     async def handle_message(self, tasks: 'FlinkTasks', context: TaskContext, child_pipeline):
         pipeline = tasks.try_get_pipeline(context)
